## Product details

Cetaphil Baby Healthy Skin Essentials Set, Includes Baby Wash & Shampoo and Daily Body Lotion, From the gentle skincare experts comes the Cetaphil Baby Healthy Skin Essentials Kit. This 2-part routine includes Cetaphil Baby Wash and Shampoo and Cetaphil Baby Daily Lotion, which work together to care for your baby's sensitive skin and protect it from dryness. Made with soothing calendula and a blend of skin-nourishing ingredients, this set is designed to make bath time a breeze and keep baby's skin soft, smooth, and moisturized. As with all Cetaphil Baby products, Cetaphil Baby Daily Lotion and Cetaphil Baby Wash and Shampoo contain no parabens, colorants, or mineral oil. Dermatologist tested, Both are hypoallergenic, gentle, and safe for everyday use.
  CETAPHIL BABY BATH ESSENTIALS KIT: Daily cleanse and moisturize routine specially designed for baby’s delicate skin
TEAR FREE WASH & SHAMPOO: This tear free formula blends into a rich lather that gently cleans your baby’s delicate skin and hair without drying
GENTLE DAILY LOTION: Moisturizer with sweet almond and sunflower seed oil gently soothes and softens baby’s skin, leaving baby’s skin nourished and protected from dryness for 24 hours
ORGANIC CALENDULA: Soothing emollient from the marigold flower helps moisturize and soften skin while leaving a fresh scent
DESIGNED FOR BABY’S SENSITIVE SKIN: Dermatologist tested to be safe and gentle, these formulas are also hypoallergenic and free from parabens, colorants and mineral oil that can irritate baby’s skin
info:
We aim to show you accurate product information. Manufacturers, suppliers and others provide what you see here, and we have not verified it.  See our disclaimer
## Specifications

Net content statement
13.5 Fl Oz Pump Bottle
Piece count
2
Items included
One bottle Wash & Shampoo 13.5oz and one bottle Daily Lotion 13.5oz
Product line
Cetaphil Baby Healthy Skin Essentials Kit 27oz
More details
## Indications

Stop Use Indications
Avoid contact with eyes
Health Concern
Immune System Support
Skin Care Concern
Dryness
Directions

## Instructions
Daily Lotion: Apply liberally and massage gently into baby's delicate skin as needed or as directed by physician. Wash & Shampoo: Wet hair & skin with water. Pour into hand or wash cloth and gently massage over hair and body to lather, then rinse.
Warranty

## Warranty information
Please be aware that the warranty terms on items offered for sale by third party Marketplace sellers may differ from those displayed in this section (if any). To confirm warranty terms on an item offered for sale by a third party Marketplace seller, please use the 'Contact seller' feature on the third party Marketplace seller's information page and request the item's warranty terms prior to purchase.
Ingredients

## Inactive Ingredients
BABY WASH & SHAMPOO INGREDIENTS: WATER, SODIUM LAURETH SULFATE, DISODIUM LAURETH SULFOSUCCINATE, COCAMIDOPROPYL BETAINE, GLYCERIN, PANTHENOL (VITAMIN B5), PEG-120 METHYL GLUCOSE DIOLEATE, GLYCOL DISTEARATE, HYDROLYZED WHEAT PROTEIN, CALENDULA OFFICINALIS FLOWER EXTRACT, ALOE BARBADENSIS LEAF JUICE POWDER, FRAGRANCE, CITRIC ACID, SODIUM BENZOATE, PHENOXYETHANOL, SODIUM CITRATE, LAURETH-4, HELIOTROPINE, POLYQUATERNIUM-10, SODIUM CHLORIDE, SODIUM HYDROXIDE, TOCOPHEROL (VITAMIN E). BABY DAILY LOTION INGREDIENTS: WATER, HELIANTHUS ANNUUS (SUNFLOWER) SEED OIL, SORBITOL, ISOPROPYL PALMITATE, OCTYLDODECANOL, POLYGLYCERYL-3 DIISOSTEARATE, GLYCERIN, PRUNUS AMYGDALUS DULCIS (SWEET ALMOND) OIL, HEXYLDECANOL, HEXYLDECYL LAURATE, PANTHENOL, CAPRYLYL GLYCOL, CARBOMER, FRAGRANCE, SODIUM COCOYL GLUTAMATE, SODIUM HYDROXIDE, DIPROPYLENE GLYCOL, CALENDULA OFFICINALIS FLOWER EXTRACT, SQUALANE, PROPYLENE GLYCOL, GLYCERYL CAPRYLATE, HELIOTROPINE, TOCOPHEROL.

## Ingredients
Wash & Shampoo: Water, Sodium Laureth Sulfate, Disodium Laureth Sulfosuccinate, Cocamidopropyl Betaine, Glycerin Panthenol (Vitamin B5) PEG-120 Methyl Glucose Dioleate, Glycol Distearate, Hydrolyzed Wheat Protein, Calendula Officinalis Flower Extract, Aloe Barbadensis Leaf Juice Powder, Fragrance, Citric Acid, Sodium Benzoate, Phenoxyethanol, Sodium Citrate, Laureth-4, Heliotropine, Polyquaternium-10, Sodium Chloride, Sodium Hydroxide, Tocopherol (Vitamin E). Daily Lotion: Water, Sorbitol Helianthus Annuus (Sunflower) Seed Oil, Isopropyl Palmitate, Octyldodecanol, Polyglycerl-3 Diisostearate, Glycerin, Panthenol (Vitamin B5), Hexyldecanol, Hexyldecyl Laurate, Prunus Amygdalus Dulcis (Sweet Almond) Oil, Caprylyl Glycol, Carbomer, Fragrance, Disodium Cocoyl Glutamate, Sodium Hydroxide, Dipropylene Glycol, Calendula Officinalis Flower Extract, Squalane, Propylene Glycol, Glyceryl Caprylate, Heliotropine, Tocopherol (Vitamin E), Glycine SOJA (Soybean) Oil.

Active Ingredients
Calendula|Aloe Vera|Sweet Almond Oil|Sunflower Oil
